@@ -450,10 +450,15 @@ def mail(adrs):
     server.quit()
 
 
-mans = []
-sous = []
-pins = []
-jihai = []
+def globalvar():
+    global mans
+    global sous
+    global pins
+    global jihai
+    mans = []
+    sous = []
+    pins = []
+    jihai = []
 def ttt(i):
     return i//4+1
 def intmahjong(i):
@@ -488,6 +493,7 @@ def intmahjong(i):
         jihai.append(str(i-27))
         return "tyun"
 def handgen(t=13):
+    globalvar()
     i = list(range(1,136))
     rm.shuffle(i)
     l = list()
@@ -512,4 +518,6 @@ def shantenquiz():
     if result == chanten:
         print(True)
     else:
-        print("False, correct answer is "+str(result))
\ No newline at end of file
+        print("False, correct answer is "+str(result))
+
+shantenquiz()
\ No newline at end of file
